@@ -64,8 +64,8 @@ class CellRendererImage(Gtk.CellRenderer):
                 w1, h1 = w0, h0
 
         scale = self.resample * self.scale
-        w2 = int(scale * (1. - self.cropL - self.cropR) * w1)
-        h2 = int(scale * (1. - self.cropT - self.cropB) * h1)
+        w2 = int(0.5 + scale * (1. - self.cropL - self.cropR) * w1)
+        h2 = int(0.5 + scale * (1. - self.cropT - self.cropB) * h1)
 
         return w0, h0, w1, h1, w2, h2, rotation
 
@@ -87,10 +87,8 @@ class CellRendererImage(Gtk.CellRenderer):
         x = cell_area.x
         y = cell_area.y
         if cell_area and w > 0 and h > 0:
-            x += self.get_property('xalign') * (
-                    cell_area.width - w - self.get_property('xpad'))
-            y += self.get_property('yalign') * (
-                    cell_area.height - h - self.get_property('ypad'))
+            x += self.get_property('xalign') * (cell_area.width - w)
+            y += self.get_property('yalign') * (cell_area.height - h)
 
         window.translate(x, y)
 
